@@ -1,19 +1,24 @@
 import uuid
-from typing import Iterable, Optional, Tuple
+from copy import deepcopy
+from typing import Iterable, Optional, Tuple, TypeVar
 
 from tdm.abstract.datamodel import AbstractDirective
 from tdm.abstract.datamodel.directive import DirectiveType
 
 
-class CreateConceptDirective(AbstractDirective):
-    __slots__ = ('_name', '_concept_type', '_notes', '_markers', '_access_level', '_id')
+_Filter = TypeVar('_Filter', bound=dict)
 
-    def __init__(self, name: str, concept_type: str, notes: Optional[str] = None, markers: Optional[Iterable[str]] = None,
-                 access_level: Optional[str] = None, id_: Optional[str] = None):
+
+class CreateConceptDirective(AbstractDirective):
+    __slots__ = ('_name', '_concept_type', '_filters', '_notes', '_markers', '_access_level', '_id')
+
+    def __init__(self, name: str, concept_type: str, filters: Tuple[_Filter, ...], notes: Optional[str] = None,
+                 markers: Optional[Iterable[str]] = None, access_level: Optional[str] = None, id_: Optional[str] = None):
         super().__init__(DirectiveType.CREATE_CONCEPT)
         self._id = id_ or self.generate_id()
         self._name = name
         self._concept_type = concept_type
+        self._filters = filters
         self._notes = notes
         self._markers = tuple(markers) if markers else None
         self._access_level = access_level
@@ -30,6 +35,10 @@ class CreateConceptDirective(AbstractDirective):
     def concept_type(self) -> str:
         return self._concept_type
 
+    @property
+    def filters(self) -> Tuple[_Filter, ...]:
+        return deepcopy(self._filters)
+
     @property
     def notes(self) -> Optional[str]:
         return self._notes
@@ -50,8 +59,8 @@ class CreateConceptDirective(AbstractDirective):
         if not isinstance(other, AbstractDirective):
             return NotImplemented
         return isinstance(other, CreateConceptDirective) and other._id == self._id and other._name == self._name and \
-            other._concept_type == self._concept_type and other._notes == self._notes and other._markers == self._markers and \
-            other._access_level == self._access_level
+            other._concept_type == self._concept_type and other._filters == self._filters and other._notes == self._notes and \
+            other._markers == self._markers and other._access_level == self._access_level
 
     def __hash__(self):
         return hash((super().__hash__(), self.concept_type, self._id))
